@@ -30,11 +30,11 @@
  * in this code to the public domain. We make this dedication for the benefit
  * of the public at large and to the detriment of our heirs and successors. We
  * intend this dedication to be an overt act of relinquishment in perpetuity of
- * all present and future rights to this code under copyright law. 
+ * all present and future rights to this code under copyright law.
  *
  * \file libtelnet.h
  *
- * \version 0.20
+ * \version 0.23
  *
  * \author Sean Middleditch <sean@sourcemud.org>
  */
@@ -42,6 +42,10 @@
 #if !defined(LIBTELNET_INCLUDE)
 #define LIBTELNET_INCLUDE 1
 
+/* standard C headers necessary for the libtelnet API */
+#include <stdarg.h>
+#include <stddef.h>
+
 /* C++ support */
 #if defined(__cplusplus)
 extern "C" {
@@ -56,6 +60,9 @@ extern "C" {
 # define TELNET_GNU_SENTINEL /*!< internal helper */
 #endif
 
+/* Disable environ macro for Visual C++ 2015. */
+#undef environ
+
 /*! Telnet state tracker object type. */
 typedef struct telnet_t telnet_t;
 
@@ -134,6 +141,7 @@ typedef struct telnet_telopt_t telnet_telopt_t;
 #define TELNET_TELOPT_ENCRYPT 38
 #define TELNET_TELOPT_NEW_ENVIRON 39
 #define TELNET_TELOPT_MSSP 70
+#define TELNET_TELOPT_COMPRESS 85
 #define TELNET_TELOPT_COMPRESS2 86
 #define TELNET_TELOPT_ZMP 93
 #define TELNET_TELOPT_EXOPL 255
@@ -171,7 +179,11 @@ typedef struct telnet_telopt_t telnet_telopt_t;
 /*@{*/
 /*! Control behavior of telnet state tracker. */
 #define TELNET_FLAG_PROXY (1<<0)
+#define TELNET_FLAG_NVT_EOL (1<<1)
 
+/* Internal-only bits in option flags */
+#define TELNET_FLAG_TRANSMIT_BINARY (1<<5)
+#define TELNET_FLAG_RECEIVE_BINARY (1<<6)
 #define TELNET_PFLAG_DEFLATE (1<<7)
 /*@}*/
 
@@ -367,7 +379,7 @@ struct telnet_t;
  * \param eh        Event handler function called for every event.
  * \param flags     0 or TELNET_FLAG_PROXY.
  * \param user_data Optional data pointer that will be passsed to eh.
- * \return Telent state tracker object.
+ * \return Telnet state tracker object.
  */
 extern telnet_t* telnet_init(const telnet_telopt_t *telopts,
 		telnet_event_handler_t eh, unsigned char flags, void *user_data);
@@ -430,6 +442,17 @@ extern void telnet_negotiate(telnet_t *telnet, unsigned char cmd,
 extern void telnet_send(telnet_t *telnet,
 		const char *buffer, size_t size);
 
+/*!
+ * Send non-command text (escapes IAC bytes and translates
+ * \\r -> CR-NUL and \\n -> CR-LF unless in BINARY mode.
+ *
+ * \param telnet Telnet state tracker object.
+ * \param buffer Buffer of bytes to send.
+ * \param size   Number of bytes to send.
+ */
+extern void telnet_send_text(telnet_t *telnet,
+		const char *buffer, size_t size);
+
 /*!
  * \brief Begin a sub-negotiation command.
  *
@@ -500,6 +523,13 @@ extern void telnet_begin_compress2(telnet_t *telnet);
 extern int telnet_printf(telnet_t *telnet, const char *fmt, ...)
 		TELNET_GNU_PRINTF(2, 3);
 
+/*!
+ * \brief Send formatted data.
+ *
+ * See telnet_printf().
+ */
+extern int telnet_vprintf(telnet_t *telnet, const char *fmt, va_list va);
+
 /*!
  * \brief Send formatted data (no newline escaping).
  *
@@ -515,26 +545,11 @@ extern int telnet_raw_printf(telnet_t *telnet, const char *fmt, ...)
 		TELNET_GNU_PRINTF(2, 3);
 
 /*!
- * \brief Send NEW-ENVIRON SEND command
+ * \brief Send formatted data (no newline escaping).
  *
- * Sends NEW-ENVIRON command to the remote end.  The cmd parameter denotes
- * the type of NEW-ENVIRON command being sent: either asking for values,
- * responding to a request for variables, or notifying about changed
- * variables.
- *
- * The count parameter is the number of variables which are being sent
- * or requested.  The following parameters must be triples, consisting
- * of the variable type (VAR or USERVAR), the variable name, and the
- * variable value.  For requests, the value should always be the empty
- * string or NULL.
- *
- * \param telnet Telnet state tracker object.
- * \param cmd    One of TELNET_ENVIRON_SEND, TELNET_ENVIRON_IS, or
- *               TELNET_ENVIRON_INFO.
- * \param count  Number of variables sent or requested.
+ * See telnet_raw_printf().
  */
-extern void telnet_newenviron_send(telnet_t *telnet, unsigned char cmd,
-		size_t count, ...);
+extern int telnet_raw_vprintf(telnet_t *telnet, const char *fmt, va_list va);
 
 /*!
  * \brief Begin a new set of NEW-ENVIRON values to request or send.
@@ -635,6 +650,13 @@ extern void telnet_send_zmp(telnet_t *telnet, size_t argc, const char **argv);
  */
 extern void telnet_send_zmpv(telnet_t *telnet, ...) TELNET_GNU_SENTINEL;
 
+/*!
+ * \brief Send a ZMP command.
+ *
+ * See telnet_send_zmpv().
+ */
+extern void telnet_send_vzmpv(telnet_t *telnet, va_list va);
+
 /*!
  * \brief Begin sending a ZMP command
  *
